@@ -10,41 +10,40 @@
 #include "vocabularyview.h"
 #include "vocabularyheaderview.h"
 
-#include "vocabularymodel.h"
-#include "vocabularyfilter.h"
 #include "vocabularydelegate.h"
+#include "vocabularyfilter.h"
 #include "vocabularymimedata.h"
+#include "vocabularymodel.h"
 
+#include "documentsettings.h"
 #include "editor/editor.h"
 #include "prefs.h"
 #include "vocabularycolumnsdialog.h"
-#include "documentsettings.h"
 
-#include <KEduVocTranslation>
 #include <KEduVocExpression>
+#include <KEduVocTranslation>
 
+#include <QApplication>
+#include <QClipboard>
 #include <QHeaderView>
 #include <QPainter>
 #include <QResizeEvent>
-#include <QClipboard>
 #include <QTimer>
-#include <QApplication>
 
-#include <KNotification>
-#include <QAction>
 #include <KActionCollection>
-#include <KToggleAction>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KNotification>
+#include <KToggleAction>
+#include <QAction>
 #include <QUrl>
-#include <sonnet/backgroundchecker.h>
 #include <languagesettings.h>
+#include <sonnet/backgroundchecker.h>
 
 using namespace Editor;
 
-VocabularyView::VocabularyView(EditorWindow * parent)
-    : QTableView(parent), m_model(0),
-      m_spellChecker(0), m_spellDialog(0)
+VocabularyView::VocabularyView(EditorWindow *parent)
+    : QTableView(parent)
 {
     installEventFilter(this);
 
@@ -75,8 +74,7 @@ VocabularyView::VocabularyView(EditorWindow * parent)
 
     m_appendEntryAction = new QAction(this);
     parent->actionCollection()->addAction(QStringLiteral("edit_append"), m_appendEntryAction);
-    parent->actionCollection()->setDefaultShortcut(
-        m_appendEntryAction, QKeySequence(Qt::Key_Insert));
+    parent->actionCollection()->setDefaultShortcut(m_appendEntryAction, QKeySequence(Qt::Key_Insert));
     m_appendEntryAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add-card")));
     m_appendEntryAction->setText(i18n("&Add New Entry"));
     connect(m_appendEntryAction, &QAction::triggered, this, &VocabularyView::appendEntry);
@@ -88,8 +86,7 @@ VocabularyView::VocabularyView(EditorWindow * parent)
 
     m_deleteEntriesAction = new QAction(this);
     parent->actionCollection()->addAction(QStringLiteral("edit_remove_selected_area"), m_deleteEntriesAction);
-    parent->actionCollection()->setDefaultShortcut(
-        m_deleteEntriesAction, QKeySequence::Delete);
+    parent->actionCollection()->setDefaultShortcut(m_deleteEntriesAction, QKeySequence::Delete);
     m_deleteEntriesAction->setIcon(QIcon::fromTheme(QStringLiteral("list-remove-card")));
     m_deleteEntriesAction->setText(i18n("&Delete Entry"));
     connect(m_deleteEntriesAction, &QAction::triggered, this, &VocabularyView::deleteSelectedEntries);
@@ -99,44 +96,39 @@ VocabularyView::VocabularyView(EditorWindow * parent)
     m_deleteEntriesAction->setStatusTip(m_deleteEntriesAction->whatsThis());
     addAction(m_deleteEntriesAction);
 
-    QAction* separator = new QAction(this);
+    QAction *separator = new QAction(this);
     separator->setSeparator(true);
     addAction(separator);
 
     m_copyAction = KStandardAction::copy(this, SLOT(slotEditCopy()), parent->actionCollection());
-    parent->actionCollection()->setDefaultShortcut(
-        m_copyAction, QKeySequence::Copy);
+    parent->actionCollection()->setDefaultShortcut(m_copyAction, QKeySequence::Copy);
     m_copyAction->setWhatsThis(i18n("Copy"));
     m_copyAction->setToolTip(m_copyAction->whatsThis());
     m_copyAction->setStatusTip(m_copyAction->whatsThis());
     addAction(m_copyAction);
 
     m_cutAction = KStandardAction::cut(this, SLOT(slotCutEntry()), parent->actionCollection());
-    parent->actionCollection()->setDefaultShortcut(
-        m_cutAction, QKeySequence::Cut);
+    parent->actionCollection()->setDefaultShortcut(m_cutAction, QKeySequence::Cut);
     m_cutAction->setWhatsThis(i18n("Cut"));
     m_cutAction->setToolTip(m_cutAction->whatsThis());
     m_cutAction->setStatusTip(m_cutAction->whatsThis());
     addAction(m_cutAction);
 
     m_pasteAction = KStandardAction::paste(this, SLOT(slotEditPaste()), parent->actionCollection());
-    parent->actionCollection()->setDefaultShortcut(
-        m_pasteAction, QKeySequence::Paste);
+    parent->actionCollection()->setDefaultShortcut(m_pasteAction, QKeySequence::Paste);
     m_pasteAction->setWhatsThis(i18n("Paste"));
     m_pasteAction->setToolTip(m_pasteAction->whatsThis());
     m_pasteAction->setStatusTip(m_pasteAction->whatsThis());
     addAction(m_pasteAction);
 
     m_selectAllAction = KStandardAction::selectAll(this, SLOT(selectAll()), parent->actionCollection());
-    parent->actionCollection()->setDefaultShortcut(
-        m_selectAllAction, QKeySequence::SelectAll);
+    parent->actionCollection()->setDefaultShortcut(m_selectAllAction, QKeySequence::SelectAll);
     m_selectAllAction->setWhatsThis(i18n("Select all rows"));
     m_selectAllAction->setToolTip(m_selectAllAction->whatsThis());
     m_selectAllAction->setStatusTip(m_selectAllAction->whatsThis());
 
     m_clearSelectionAction = KStandardAction::deselect(this, SLOT(clearSelection()), parent->actionCollection());
-    parent->actionCollection()->setDefaultShortcut(
-        m_clearSelectionAction, QKeySequence::Deselect);
+    parent->actionCollection()->setDefaultShortcut(m_clearSelectionAction, QKeySequence::Deselect);
     m_clearSelectionAction->setWhatsThis(i18n("Deselect all rows"));
     m_clearSelectionAction->setToolTip(m_clearSelectionAction->whatsThis());
     m_clearSelectionAction->setStatusTip(m_clearSelectionAction->whatsThis());
@@ -154,32 +146,30 @@ VocabularyView::VocabularyView(EditorWindow * parent)
     connect(vocabularyColumnsDialogAction, &QAction::triggered, this, &VocabularyView::slotShowVocabularyColumnsDialog);
 }
 
-void VocabularyView::setFilter(VocabularyFilter * model)
+void VocabularyView::setFilter(VocabularyFilter *model)
 {
     QTableView::setModel(model);
 
     m_model = model;
-    connect(selectionModel(), &QItemSelectionModel::currentChanged,
-            this, &VocabularyView::slotCurrentChanged);
-    connect(selectionModel(), &QItemSelectionModel::selectionChanged,
-            this, &VocabularyView::slotSelectionChanged);
+    connect(selectionModel(), &QItemSelectionModel::currentChanged, this, &VocabularyView::slotCurrentChanged);
+    connect(selectionModel(), &QItemSelectionModel::selectionChanged, this, &VocabularyView::slotSelectionChanged);
     slotSelectionChanged(QItemSelection(), QItemSelection());
 }
 
-void VocabularyView::slotCurrentChanged(const QModelIndex & current, const QModelIndex & previous)
+void VocabularyView::slotCurrentChanged(const QModelIndex &current, const QModelIndex &previous)
 {
     Q_UNUSED(previous);
-    KEduVocExpression* entry = 0;
+    KEduVocExpression *entry = nullptr;
     if (current.isValid()) {
-        entry =  model()->data(current, VocabularyModel::EntryRole).value<KEduVocExpression*>();
+        entry = model()->data(current, VocabularyModel::EntryRole).value<KEduVocExpression *>();
     }
-    emit translationChanged(entry, VocabularyModel::translation(current.column()));
+    Q_EMIT translationChanged(entry, VocabularyModel::translation(current.column()));
 }
 
 void VocabularyView::reset()
 {
     QTableView::reset();
-    emit translationChanged(0, 0);
+    Q_EMIT translationChanged(nullptr, 0);
 
     QList<int> visibleColumns;
     if (m_doc) {
@@ -225,7 +215,7 @@ void VocabularyView::saveColumnVisibility() const
     ds.setVisibleColumns(visibleList);
     ds.save();
 
-    QByteArray saveState = horizontalHeader()->saveState();
+    horizontalHeader()->saveState();
     KConfig parleyConfig(QStringLiteral("parleyrc"));
     KConfigGroup documentGroup(&parleyConfig, "Document " + m_doc->url().url());
     documentGroup.writeEntry("VocabularyColumns", horizontalHeader()->saveState());
@@ -250,17 +240,23 @@ void VocabularyView::appendChar(const QChar &c)
 void VocabularyView::deleteSelectedEntries(bool askConfirmation)
 {
     QSet<int> rows;
-    foreach(const QModelIndex & index, selectionModel()->selectedIndexes()) {
+    const QModelIndexList selectedIndexes = selectionModel()->selectedIndexes();
+    for (const QModelIndex &index : selectedIndexes) {
         rows.insert(index.row());
     }
 
     bool del = true;
     if (askConfirmation) {
-        del = KMessageBox::Continue == KMessageBox::warningContinueCancel(this, i18np("Do you really want to delete the selected entry?", "Do you really want to delete the selected %1 entries?", rows.count()), i18n("Delete"), KStandardGuiItem::del());
+        del = KMessageBox::Continue
+            == KMessageBox::warningContinueCancel(
+                  this,
+                  i18np("Do you really want to delete the selected entry?", "Do you really want to delete the selected %1 entries?", rows.count()),
+                  i18n("Delete"),
+                  KStandardGuiItem::del());
     }
 
     if (del) {
-        emit translationChanged(0, 0);
+        Q_EMIT translationChanged(nullptr, 0);
         while (!selectionModel()->selectedIndexes().isEmpty()) {
             m_model->removeRows(selectionModel()->selectedIndexes()[0].row(), 1, QModelIndex());
         }
@@ -284,15 +280,18 @@ void VocabularyView::slotEditPaste()
     const VocabularyMimeData *vocMimeData = qobject_cast<const VocabularyMimeData *>(mimeData);
     if (vocMimeData) {
         qDebug() << "Clipboard contains vocabulary mime data.";
-        foreach(const VocabularyMimeData::MimeExpression & mimeEntry, vocMimeData->expressionList()) {
+        QList<VocabularyMimeData::MimeExpression> expressionList = vocMimeData->expressionList();
+        for (const VocabularyMimeData::MimeExpression &mimeEntry : qAsConst(expressionList)) {
             KEduVocExpression *pasteExpression = new KEduVocExpression(mimeEntry.expression);
             m_model->appendEntry(pasteExpression);
 
             // find word type (create if not found)
             KEduVocWordType *type = m_doc->wordTypeContainer();
-            foreach(int translation, mimeEntry.wordTypes.keys()) {
+            for (auto iter = mimeEntry.wordTypes.cbegin(); iter != mimeEntry.wordTypes.cend(); ++iter) {
+                const int translation = iter.key();
                 // append if needed
-                foreach(const QString & typeName, mimeEntry.wordTypes.value(translation).wordType) {
+                const QStringList wordType = mimeEntry.wordTypes.value(translation).wordType;
+                for (const QString &typeName : wordType) {
                     qDebug() << mimeEntry.wordTypes.value(translation).wordType;
                     KEduVocContainer *childType = type->childContainer(typeName);
                     if (!childType) {
@@ -300,7 +299,7 @@ void VocabularyView::slotEditPaste()
                         childType = new KEduVocWordType(typeName);
                         type->appendChildContainer(childType);
                     }
-                    type = static_cast<KEduVocWordType*>(childType);
+                    type = static_cast<KEduVocWordType *>(childType);
                 }
                 pasteExpression->translation(translation)->setWordType(type);
                 // check for special type stuff
@@ -315,7 +314,7 @@ void VocabularyView::slotEditPaste()
         qDebug() << "Clipboard contains text data.";
         // split at newline
         QStringList lines = clipboard->text().split('\n');
-        foreach(QString line, lines) {
+        for (const QString &line : qAsConst(lines)) {
             // split at tabs or semicolon:
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             m_model->appendEntry(new KEduVocExpression(line.split(QRegExp(QStringLiteral("[\t;]")), QString::KeepEmptyParts)));
@@ -348,15 +347,6 @@ void VocabularyView::setDocument(const std::shared_ptr<KEduVocDocument> &doc)
     QTimer::singleShot(0, this, SLOT(reset()));
 }
 
-/**
- * Set the translator to be used by the delegate
- * @param translator
- */
-void VocabularyView::setTranslator(Translator* translator)
-{
-    m_vocabularyDelegate->setTranslator(translator);
-}
-
 void VocabularyView::slotShowVocabularyColumnsDialog()
 {
     VocabularyColumnsDialog *dialog = new VocabularyColumnsDialog(m_doc.get(), this);
@@ -393,7 +383,9 @@ void VocabularyView::checkSpelling(int language)
     m_spellChecker->changeLanguage(spellCode);
     if (!m_spellChecker->speller().isValid()) {
         qDebug() << "Invalid Language, popup here!";
-        KNotification::event(KNotification::Warning, i18nc("@title of a popup", "No Spell Checker Available"), i18nc("@popupmessage", "Either the language set up is incorrect or no spellchecker was installed for this locale: %1.", locale));
+        KNotification::event(KNotification::Warning,
+                             i18nc("@title of a popup", "No Spell Checker Available"),
+                             i18nc("@popupmessage", "Either the language set up is incorrect or no spellchecker was installed for this locale: %1.", locale));
     }
     m_spellDialog->show();
     continueSpelling();
@@ -422,7 +414,7 @@ void VocabularyView::selectIndex(const QModelIndex &newIndex)
     scrollTo(newIndex);
 }
 
-bool VocabularyView::eventFilter(QObject* obj, QEvent* event)
+bool VocabularyView::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::KeyPress && Prefs::smartAppend()) {
         QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
@@ -436,7 +428,7 @@ bool VocabularyView::eventFilter(QObject* obj, QEvent* event)
     return QObject::eventFilter(obj, event);
 }
 
-void VocabularyView::misspelling(const QString & word, int start)
+void VocabularyView::misspelling(const QString &word, int start)
 {
     Q_UNUSED(word)
     Q_UNUSED(start)
@@ -444,7 +436,7 @@ void VocabularyView::misspelling(const QString & word, int start)
     selectIndex(index);
 }
 
-void VocabularyView::spellingReplace(const QString & oldWord, int start, const QString & newWord)
+void VocabularyView::spellingReplace(const QString &oldWord, int start, const QString &newWord)
 {
     qDebug() << oldWord << start << newWord;
     QModelIndex index = m_model->index(m_spellRow, m_spellColumn);
@@ -458,3 +450,5 @@ QModelIndexList VocabularyView::getSelectedIndexes() const
 {
     return selectionModel()->selectedIndexes();
 }
+
+#include "moc_vocabularyview.cpp"
