@@ -6,28 +6,27 @@
 
 #include "generaloptions.h"
 
-#include <QCheckBox>
 #include <KLocalizedString>
+#include <QCheckBox>
 
-#include <QSpinBox>
 #include <KFile>
+#include <QSpinBox>
 
 #include "prefs.h"
 
-static const char *separator_id[] = {
-    ";",              // 0
-    "#",              // 1
-    "!",              // 2
-    "|",              // 3
-    ",",              // 4
-    "\t",             // 5
-    "  ",             // 6
-    ":",              // 7
-    "::",             // 8
-    0
-};
+static const char *separator_id[] = {";", // 0
+                                     "#", // 1
+                                     "!", // 2
+                                     "|", // 3
+                                     ",", // 4
+                                     "\t", // 5
+                                     "  ", // 6
+                                     ":", // 7
+                                     "::", // 8
+                                     nullptr};
 
-GeneralOptions::GeneralOptions(QWidget* parent) : QWidget(parent)
+GeneralOptions::GeneralOptions(QWidget *parent)
+    : QWidget(parent)
 {
     setupUi(this);
     connect(kcfg_AutoBackup, &QCheckBox::toggled, kcfg_BackupTime, &QSpinBox::setEnabled);
@@ -37,7 +36,6 @@ GeneralOptions::GeneralOptions(QWidget* parent) : QWidget(parent)
     kcfg_BackupTime->setEnabled(kcfg_AutoBackup->isChecked());
 }
 
-
 void GeneralOptions::fillWidgets()
 {
     kcfg_SeparatorCombo->addItem(i18nc("CSV separator", ";"));
@@ -59,10 +57,8 @@ void GeneralOptions::updateWidgets()
             break;
         }
     }
-
 }
 
-
 bool GeneralOptions::hasChanged()
 {
     if (kcfg_SeparatorCombo->currentIndex() < 0)
@@ -71,7 +67,6 @@ bool GeneralOptions::hasChanged()
     return (separator_id[kcfg_SeparatorCombo->currentIndex()] != Prefs::separator());
 }
 
-
 bool GeneralOptions::isDefault()
 {
     if (kcfg_SeparatorCombo->currentIndex() < 0)
@@ -79,10 +74,11 @@ bool GeneralOptions::isDefault()
     return !strcmp(separator_id[kcfg_SeparatorCombo->currentIndex()], "\t");
 }
 
-
 void GeneralOptions::updateSettings()
 {
     if (kcfg_SeparatorCombo->currentIndex() < 0)
         return;
     Prefs::setSeparator((separator_id[kcfg_SeparatorCombo->currentIndex()]));
 }
+
+#include "moc_generaloptions.cpp"
